import {ScreenChartProps, SingleLayoutConf} from "../types/ScreenChart.typing.ts";
import {mapHeight, mapWidth} from "./mapGEOStyle.ts";

export const gridItemStyle = function (item: SingleLayoutConf, props: ScreenChartProps) {
    return {
        gridColumn: `${item.x + 1} / span ${item.w}`,
        gridRow: `${item.y + 1} / span ${item.h}`,
        background: '#f1f1f1',
        boxSizing: 'border-box',
        // @ts-ignore
        padding: `${mapHeight(props.gridItemPadding)}px ${mapWidth(props.gridItemPadding)}px ${mapHeight(props.gridItemPadding)}px ${mapWidth(props.gridItemPadding)}px`,
        fontSize: `${mapWidth(14)}px`
    }
}

export function getAllGridSize(items: Array<SingleLayoutConf>) {
    let maxCol = 0;
    let maxRow = 0;

    for (const item of items) {
        // 计算当前元素的右边界和下边界
        const rightEdge = item.x + item.w;
        const bottomEdge = item.y + item.h;

        // 更新最大列数和行数
        if (rightEdge > maxCol) {
            maxCol = rightEdge;
        }
        if (bottomEdge > maxRow) {
            maxRow = bottomEdge;
        }
    }

    return { rows: maxRow, cols: maxCol };
}

export const mapContainerStyle = function (props: ScreenChartProps, gridConfig: { rows: number, cols: number}) {
    return {
        display: 'grid',
        // @ts-ignore
        gridRowGap: mapHeight(props.gap) + 'px',
        // @ts-ignore
        gridColumnGap: mapWidth(props.gap) + 'px',
        gridTemplateColumns: `repeat(${gridConfig.cols}, 1fr)`,
        gridTemplateRows: `repeat(${gridConfig.rows}, 1fr)`,
        boxSizing: 'border-box',
        // @ts-ignore
        padding: `${mapHeight(props.containerPadding)}px ${mapWidth(props.containerPadding)}px ${mapHeight(props.containerPadding)}px ${mapWidth(props.containerPadding)}px`,
    }
}